@@ -40,7 +40,7 @@ from mo_parsing.whitespaces import Whitespace
 whitespaces.NO_WHITESPACE = Whitespace("").use()
 whitespaces.STANDARD_WHITESPACE = Whitespace().use()
 
-from mo_parsing.infix import LEFT_ASSOC, RIGHT_ASSOC, infixNotation
+from mo_parsing.infix import LEFT_ASSOC, RIGHT_ASSOC, infix_notation
 from mo_parsing.regex import Regex
 from mo_parsing.tokens import (
     CaselessKeyword,
@@ -113,6 +113,6 @@ __all__ = [
     "Char",
     "LEFT_ASSOC",
     "RIGHT_ASSOC",
-    "infixNotation",
+    "infix_notation",
     "CloseMatch",
 ]
